function hasClassName(element, name) {
	return element.className == undefined ? false : element.className.indexOf(name) != -1;
}

function addClassName(element, name) {
	if ( element.className != undefined && !hasClassName(element, name) ) {
		element.className += " " + name;
	}
}

function removeClassName(element, name) {
	if ( element.className != undefined ) {
		var index = element.className.indexOf(name);
		if ( index != -1 ) {
			var _1 = element.className.substr(0, index - 1);
			var _2 = element.className.substr(index + name.length);
			element.className = _1 + _2;
		}
	}
}

/** 
 *  For all elements other than an element having 'open-close-title' class under an element 'open-close-container' class, 
 *  switch 'display' style between ''(default) and 'none' by clicking the container element.
 *  a title element handles onclick event.
 */
function toggleOpenCloseContainer(initiator) {

	var titleClass = 'open-close-title';
	var containerClass = 'open-close-container';
	
	var body = document.body;
	
	// Find the most nearest 'open-close-container' element.
	var container = initiator;//.parentNode;
	while ( container != body && !hasClassName(container, containerClass) ) {
		container = container.parentNode;
	}
	if ( container == body ) {
		// no container element found.
		return;
	}
	
	// Toggle 'display' style between 'none' and ''.
	var children = container.childNodes;
	if ( hasClassName(container, "closed") ) {
		for (var i = 0; i < children.length; i++) {
			var element = children[i];
			if ( element.nodeType == 1 && !hasClassName(element, titleClass) ) {//element != title ) {
				var display = element.style.display;
				if ( display === "none" ) {
					element.style.display = "";
				}
			}
		}
		removeClassName(container, "closed");
	}
	else {
		for (var i = 0; i < children.length; i++) {
			var element = children[i];
			if ( element.nodeType == 1 && !hasClassName(element, titleClass) ) {// element != title ) {
				var display = element.style.display;
				if ( display === null || display === "" ) {
					element.style.display = "none";
				}
			}
		}
		addClassName(container, "closed");
	}
}

function handleToggleOpenCloseContainer(event) {
	toggleOpenCloseContainer(event.target);
}

// Pseudo page
function activatePage(activePageId) {
	var pageClass = 'page';
	var body = document.body;

	//alert('activePage: ' + activePageId);
	var activePage = document.getElementById(activePageId);
	if ( activePage == body ) {
		// no page element found.
		//alert("no active page found.");
		return;
	}
	
	// Close inactive pages.
	var pages = document.getElementsByClassName("page");
	for (var i = 0; i < pages.length; i++) {
		var page = pages[i];
		if ( page != activePage ) {
			pages[i].style.display = 'none';
		}
	}
	
	// Scroll to top of the page.
	window.scrollTo(0, 0);
	
	// Open active page.
	activePage.style.display = ''; // Set no style to display it.
}
function handleActivatePage(event) {
	activatePage(event.target.href.substr(event.target.href.indexOf('#') + 1));
}

// Apply function recursively all children.
function applyFunction(element, func) {
	func(element);

	var children = element.childNodes;
	for (var _i = 0; _i < children.length; _i++) {
		applyFunction(children[_i], func);
	}
};

var _lastEvent = undefined;

function init() {
	var nodes;


	// Pseudo page
	var nodes = document.getElementsByClassName("page");
	for (var i = 0; i < nodes.length; i++) {
		if ( hasClassName(nodes[i], 'closed') ) {
			nodes[i].style.display = 'none';
		}
	}
	var nodes = document.getElementsByClassName("auto-page-triggers");
	for (var i = 0; i < nodes.length; i++) {
		applyFunction(nodes[i], function(element) {
			if ( element instanceof HTMLAnchorElement ) {
				element.onclick = handleActivatePage;
			}
		});
	}
	nodes = document.getElementsByClassName("page-trigger");
	for (var i = 0; i < nodes.length; i++) {
		var element = nodes[i];
		if ( element instanceof HTMLAnchorElement ) {
			element.onclick = handleActivatePage;
		}
	}

	// Open & Close box element.
	var nodes = document.getElementsByClassName("open-close-title");
	for (var i = 0; i < nodes.length; i++) {
		nodes[i].onclick = handleToggleOpenCloseContainer;
	}
	
	var nodes = document.getElementsByClassName("open-close-container");
	for (var i = 0; i < nodes.length; i++) {
		if ( hasClassName(nodes[i], 'closed') && nodes[i].hasChildNodes() ) {
			removeClassName(nodes[i], 'closed');
			toggleOpenCloseContainer(nodes[i].firstChild);
		}
	}
	
	// Hover workaround
	nodes = document.getElementsByClassName('touch-hover');
	for (var i = 0; i < nodes.length; i++) {
		applyFunction(nodes[i], function(element) {
			if ( element instanceof HTMLAnchorElement ) {
				element.ontouchstart = function() {
					var e = event.touches[0];
					addClassName(e.target, "touchhover");
					_lastEvent = e;
				};
				element.ontouchend = function() {
					removeClassName(_lastEvent.target, "touchhover");
				}
			}
		});
	}
}

window.onload = init;

